@@ -51,6 +51,13 @@ namespace HuginQueue
         const bool runCPClean = config->Read(wxT("/Assistant/AutoCPClean"), HUGIN_ASS_AUTO_CPCLEAN) != 0;
         double scale;
         config->Read(wxT("/Assistant/panoDownsizeFactor"), &scale, HUGIN_ASS_PANO_DOWNSIZE_FACTOR);
+        bool hasUserDefinedOutputIni = (config->Read("/Assistant/UserDefinedOutputOption", 0l) == 1l);
+        if (hasUserDefinedOutputIni)
+        {
+            // user defined output options, read from ini
+            const wxFileName iniFilename(hugin_utils::GetUserAppDataDir(), "output.ini");
+            hasUserDefinedOutputIni = iniFilename.FileExists();
+        };
 
         bool runicp = (pano.getNrOfCtrlPoints() == 0);
         if (!runicp)
@@ -109,22 +116,32 @@ namespace HuginQueue
         if (pano.getNrOfImages() == 1)
         {
             commands->push_back(new NormalCommand(GetInternalProgram(ExePath, wxT("autooptimiser")),
-                wxT("-a -s -o ") + quotedProject + wxT(" ") + quotedProject, _("Optimizing...")));
+                (hasUserDefinedOutputIni ? wxT("-a -o ") : wxT("-a -s -o ")) + quotedProject + wxT(" ") + quotedProject, _("Optimizing...")));
         }
         else
         {
             commands->push_back(new NormalCommand(GetInternalProgram(ExePath, wxT("autooptimiser")),
-                wxT("-a -m -l -s -o ") + quotedProject + wxT(" ") + quotedProject, _("Optimizing...")));
+                (hasUserDefinedOutputIni ? wxT("-a -m -l -o ") : wxT("-a -m -l -s -o ")) + quotedProject + wxT(" ") + quotedProject, _("Optimizing...")));
         };
         wxString panoModifyArgs;
-        // if necessary scale down final pano
-        if (scale <= 1.0)
+        wxString label(_("Searching for best crop..."));
+        if(hasUserDefinedOutputIni)
         {
-            panoModifyArgs << wxT("--canvas=") << hugin_utils::roundi(scale * 100) << wxT("% ");
+            const wxFileName iniFilename(hugin_utils::GetUserAppDataDir(), "output.ini");
+            panoModifyArgs << wxT("--ini=") << wxEscapeFilename(iniFilename.GetFullPath()) << wxT(" ");
+            label = wxString::Format("Setting options from %s", iniFilename.GetFullName().c_str());
+        }
+        else
+        {
+            // if necessary scale down final pano
+            if (scale <= 1.0)
+            {
+                panoModifyArgs << wxT("--canvas=") << hugin_utils::roundi(scale * 100) << wxT("% ");
+            };
+            panoModifyArgs.Append(wxT("--crop=AUTO "));
         };
-        panoModifyArgs.Append(wxT("--crop=AUTO --output=") + quotedProject + wxT(" ") + quotedProject);
-        commands->push_back(new NormalCommand(GetInternalProgram(ExePath, wxT("pano_modify")),
-            panoModifyArgs, _("Searching for best crop...")));
+        panoModifyArgs.Append(wxT("--output=") + quotedProject + wxT(" ") + quotedProject);
+        commands->push_back(new NormalCommand(GetInternalProgram(ExePath, wxT("pano_modify")), panoModifyArgs, label));
         return commands;
     }
     
