@@ -270,6 +270,7 @@ int MyExecPanel::ExecQueue(HuginQueue::CommandQueue* queue)
     {
         return 0;
     };
+    m_stopWatch.Start();
     return ExecNextQueue();
 };
 
@@ -353,6 +354,9 @@ void MyExecPanel::AddToOutput(wxInputStream & s)
                 if (currLine.Last() != wxChar('\n') )
                     currLine.Trim();
             }
+        } else if (c == 0x0) {
+            // ignore 0x0 chars
+            continue;
         } else if (c == 0x0d) {
             lastCR=true;
 #ifndef __WXMSW__
@@ -386,7 +390,7 @@ void MyExecPanel::AddToOutput(wxInputStream & s)
 
     m_textctrl->Replace(m_lastLineStart, m_textctrl->GetLastPosition(), currLine);
     size_t lret = currLine.find_last_of(wxChar('\n'));
-    if (lret > 0 && lret+1 < currLine.size()) {
+    if (lret != wxString::npos && lret>0 && lret+1 < currLine.size()) {
         m_lastLineStart += lret+1;
     }
 }
@@ -467,6 +471,19 @@ void MyExecPanel::OnProcessTerminated(MyPipedProcess *process, int pid, int stat
             };
         };
     };
+    {
+        // add elapsed time
+        const long duration = hugin_utils::roundi(m_stopWatch.Time() / 1000.0);
+        if (duration >= 60)
+        {
+            std::ldiv_t result=std::ldiv(duration, 60l);
+            *m_textctrl << "\n" << wxString::Format(_("Process took %ld:%2ld min"), result.quot, result.rem) << "\n";
+        }
+        else
+        {
+            *m_textctrl << "\n" << wxString::Format(_("Process took %ld s"), duration) << "\n";
+        };
+    };
     // send termination to parent
     if (this->GetParent())
     {
