@@ -123,6 +123,13 @@ namespace HuginQueue
             outputFile << wxT("FOV: ") << wxString::Format(wxT("%.0f"), opts.getHFOV()) << wxT(" x ") << wxString::Format(wxT("%.0f"), opts.getVFOV()) << linebreak;
             outputFile << wxT("Ev: ") << wxString::Format(wxT("%.2f"), opts.outputExposureValue) << endl;
             outputFile << wxT("-f") << endl;
+            if (exifToolVersion >= 11.53)
+            {
+                // add composite image tags from EXIF 2.32
+                // these are supported by exiftool 11.53 and later
+                outputFile << wxT("-CompositeImage=General Composite Image") << endl;
+                outputFile << wxString::Format(wxT("-CompositeImageCount=%lu %lu"), (unsigned long)pano.getNrOfImages(), (unsigned long)pano.getActiveImages().size()) << endl;
+            };
             if (generateGPanoTags)
             {
                 //GPano tags are only indented for equirectangular images
