@@ -222,8 +222,8 @@ void LensCalImageCtrl::Resize( wxSizeEvent & e )
 {
     if(m_imageLines==NULL || !m_img.Ok() || (m_previewMode==mode_edge && !m_edge.Ok()))
     {
-        m_scaled_img.Create(0,0);
-        m_display_img.Create(0,0);
+        m_scaled_img = wxBitmap();
+        m_display_img = wxBitmap();
         Refresh(true);
         return;
     }
