@@ -108,21 +108,10 @@ class HuginExecutor : public APP
         wxFileName inputFile(m_input);
         inputFile.Normalize();
         std::string input(inputFile.GetFullPath().mb_str(HUGIN_CONV_FILENAME));
-        std::ifstream prjfile(input.c_str());
-        if (!prjfile.good())
+        if (!pano.ReadPTOFile(input, hugin_utils::getPathPrefix(input)))
         {
-            std::cerr << "could not open script : " << input << std::endl;
-            return -1;
-        }
-        pano.setFilePrefix(hugin_utils::getPathPrefix(input));
-        AppBase::DocumentData::ReadWriteError err = pano.readData(prjfile);
-        if (err != AppBase::DocumentData::SUCCESSFUL)
-        {
-            std::cerr << "error while parsing panos tool script: " << input << std::endl;
-            std::cerr << "DocumentData::ReadWriteError code: " << err << std::endl;
-            return -1;
-        }
-        prjfile.close();
+            return 1;
+        };
 
         HuginQueue::CommandQueue* commands;
         wxArrayString tempfiles;
