@@ -25,7 +25,14 @@
 
 #include "panoinc.h"
 #include "hugin_config.h"
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#include <epoxy/gl.h>
+#ifdef __WXMSW__
+#include <epoxy/wgl.h>
+#endif
+#else
 #include <GL/glew.h>
+#endif
 #include <base_wx/platform.h>
 #include <wx/settings.h>
 #include <wx/dcclient.h>
@@ -39,7 +46,9 @@
 #include "GLPreviewFrame.h"
 #include "hugin/huginApp.h"
 
+#if !defined HAVE_EPOXY || !HAVE_EPOXY
 bool GLViewer::initialised_glew=false;
+#endif
 ViewState * GLViewer::m_view_state = NULL;
 size_t GLViewer::m_view_state_observer = 0;
 
@@ -121,6 +130,19 @@ void GLViewer::SetUpContext()
         // It appears we are setting up for the first time.
         started_creation = true;
         
+#if defined HAVE_EPOXY && HAVE_EPOXY
+        // check the openGL capabilities.
+        if (!(epoxy_gl_version() > 11 && epoxy_has_gl_extension("GL_ARB_multitexture")))
+        {
+            started_creation = false;
+            wxConfigBase::Get()->Write(wxT("DisableOpenGL"), 1l);
+            wxConfigBase::Get()->Flush();
+            DEBUG_ERROR("Sorry, OpenGL 1.1 + GL_ARB_multitexture extension required.");
+            frame->Close();
+            wxMessageBox(_("Sorry, the fast preview window requires a system which supports OpenGL version 1.1 with the GL_ARB_multitexture extension.\nThe fast preview cannot be opened.\n\nHugin has been configured to start without fast preview.\nPlease restart Hugin."), _("Error"), wxOK | wxICON_ERROR);
+            return;
+        }
+#else
         if (!initialised_glew)
         {
             // initialise the glew library, if not done it before.
@@ -148,6 +170,7 @@ void GLViewer::SetUpContext()
             wxMessageBox(_("Sorry, the fast preview window requires a system which supports OpenGL version 1.1 with the GL_ARB_multitexture extension.\nThe fast preview cannot be opened.\n\nHugin has been configured to start without fast preview.\nPlease restart Hugin."),_("Error"), wxOK | wxICON_ERROR);
             return;
         }
+#endif
 
         setUp();
 #ifdef __WXGTK__
