@@ -108,6 +108,8 @@ void MaskImageCtrl::SetMaskMode(bool newMaskMode)
             m_maskEditState=CROP_SHOWING;
         };
     };
+    ClearOverlay();
+    update();
 };
 
 void MaskImageCtrl::setImage(const std::string & file, HuginBase::MaskPolygonVector newMask, HuginBase::MaskPolygonVector masksToDraw, ImageRotation rot)
@@ -155,12 +157,15 @@ void MaskImageCtrl::setImage(const std::string & file, HuginBase::MaskPolygonVec
         m_imgRotation=rot;
         setActiveMask(UINT_MAX,false);
         rescaleImage();
+        update();
         Scroll(m_oldScrollPosX, m_oldScrollPosY);
     }
     else
     {
         m_maskEditState = NO_IMAGE;
         m_bitmap = wxBitmap();
+        m_disabledBitmap = m_bitmap;
+        m_overlay.Reset();
         // delete the image (release shared_ptr)
         // create an empty image.
         m_img = ImageCache::EntryPtr(new ImageCache::Entry);
@@ -639,7 +644,6 @@ void MaskImageCtrl::OnLeftMouseDown(wxMouseEvent& mouse)
             {
                 m_cropMode = HuginBase::SrcPanoImage::CROP_CIRCLE;
             };
-            ClearOverlay();
             break;
         default:
             // otherwise do nothing
@@ -761,6 +765,7 @@ void MaskImageCtrl::OnLeftMouseUp(wxMouseEvent& mouse)
             m_maskEditState=CROP_SHOWING;
             SetCursor(wxNullCursor);
             m_editPanel->UpdateCrop(true);
+            doUpdate = true;
             break;
         default:
             if(HasCapture())
@@ -1362,10 +1367,14 @@ void MaskImageCtrl::OnDraw(wxDC & dc)
 
 void MaskImageCtrl::ClearOverlay()
 {
-    wxClientDC dc(this);
-    PrepareDC(dc);
-    wxDCOverlay overlaydc(m_overlay, &dc);
-    overlaydc.Clear();
+    {
+        wxClientDC dc(this);
+        PrepareDC(dc);
+        wxDCOverlay overlaydc(m_overlay, &dc);
+        overlaydc.Clear();
+    };
+    // before reseting the wxOverlay we need to disconnet it from wxDCOverlay
+    // so destruct wxDCOverlay before calling Reset()
     m_overlay.Reset();
 }
 
@@ -1472,6 +1481,8 @@ void MaskImageCtrl::rescaleImage()
         SetVirtualSize(m_imageSize.GetWidth(), m_imageSize.GetHeight());
     };
     SetScrollRate(1, 1);
+    // reset overlay
+    m_overlay.Reset();
     Refresh(true);
 };
 
@@ -1544,7 +1555,6 @@ void MaskImageCtrl::setScale(double factor)
         // keep existing scale focussed.
         rescaleImage();
     }
-    m_overlay.Reset();
 };
 
 double MaskImageCtrl::calcAutoScaleFactor(wxSize size)
