@@ -42,37 +42,76 @@ void PanosphereOverviewCameraTool::Activate()
 
 void PanosphereOverviewCameraTool::MouseMoveEvent(double x, double y, wxMouseEvent & e)
 {
-    if (down) {
-        hugin_utils::FDiff2D pos = helper->GetMouseScreenPosition();
-        PanosphereOverviewVisualizationState*  state = static_cast<PanosphereOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
-        //FIXME: include a scale factor for the panosphere
-        double scale = (state->getR() - state->getSphereRadius()) / 40000.0;
-        state->setAngX((pos.x - start_x) * scale + start_angx);
-        double ey = (pos.y - start_y) * scale + start_angy;
-        if (ey >= M_PI / 2.0) {ey = M_PI / 2.0 - 0.0001;}
-        if (ey <= -M_PI / 2.0) {ey = -M_PI / 2.0 + 0.0001;}
-        state->setAngY(ey);
-        state->Redraw();
-    }
+    if (down)
+    {
+        if (e.ButtonIsDown(wxMOUSE_BTN_ANY))
+        {
+            hugin_utils::FDiff2D pos = helper->GetMouseScreenPosition();
+            PanosphereOverviewVisualizationState* state = static_cast<PanosphereOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
+            //FIXME: include a scale factor for the panosphere
+            double scale = (state->getR() - state->getSphereRadius()) / 40000.0;
+            if (state->isInsideView())
+            {
+                if (e.ButtonIsDown(wxMOUSE_BTN_MIDDLE))
+                {
+                    // invert mouse for middle button panning in inside view
+                    state->setAngX(start_angx - (pos.x - start_x) * scale);
+                    double ey = (pos.y - start_y) * scale + start_angy;
+                    if (ey >= M_PI / 2.0) { ey = M_PI / 2.0 - 0.0001; }
+                    if (ey <= -M_PI / 2.0) { ey = -M_PI / 2.0 + 0.0001; }
+                    state->setAngY(ey);
+                }
+                else
+                {
+                    state->setAngX((pos.x - start_x) * scale + start_angx);
+                    double ey = start_angy - (pos.y - start_y) * scale;
+                    if (ey >= M_PI / 2.0) { ey = M_PI / 2.0 - 0.0001; }
+                    if (ey <= -M_PI / 2.0) { ey = -M_PI / 2.0 + 0.0001; }
+                    state->setAngY(ey);
+                };
+            }
+            else
+            {
+                // outside view
+                state->setAngX((pos.x - start_x) * scale + start_angx);
+                double ey = (pos.y - start_y) * scale + start_angy;
+                if (ey >= M_PI / 2.0) { ey = M_PI / 2.0 - 0.0001; }
+                if (ey <= -M_PI / 2.0) { ey = -M_PI / 2.0 + 0.0001; }
+                state->setAngY(ey);
+            };
+            state->Redraw();
+        }
+        else
+        {
+            // no button pressed any more, reset flag
+            down = false;
+        };
+    };
 }
 
 void PanosphereOverviewCameraTool::MouseButtonEvent(wxMouseEvent &e)
 {
 //    DEBUG_DEBUG("mouse ov drag button");
-    if ((e.ButtonDown() && (!helper->IsMouseOverPano() || e.CmdDown() || e.AltDown())) || e.MiddleDown()) {
-        down = true;
-        hugin_utils::FDiff2D pos = helper->GetMouseScreenPosition();
-        start_x = pos.x;
-        start_y = pos.y;
-        PanosphereOverviewVisualizationState*  state = static_cast<PanosphereOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
-        start_angx = state->getAngX();
-        start_angy = state->getAngY();
-    }
-    if (e.ButtonUp()) {
-        if (down) {
+    if (e.ButtonDown())
+    {
+        PanosphereOverviewVisualizationState* state = static_cast<PanosphereOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
+        if (state->isInsideView() || (!helper->IsMouseOverPano() || e.CmdDown() || e.AltDown() || e.MiddleDown()))
+        {
+            down = true;
+            hugin_utils::FDiff2D pos = helper->GetMouseScreenPosition();
+            start_x = pos.x;
+            start_y = pos.y;
+            start_angx = state->getAngX();
+            start_angy = state->getAngY();
+        };
+    };
+    if (e.ButtonUp())
+    {
+        if (down)
+        {
             down = false;
-        }
-    }
+        };
+    };
 }
 
 
@@ -96,10 +135,36 @@ void PanosphereOverviewCameraTool::ChangeZoomLevel(bool zoomIn, double scale) {
     }
 }
 
+void PanosphereOverviewCameraTool::ChangeFOV(bool zoomIn)
+{
+    PanosphereOverviewVisualizationState* state = static_cast<PanosphereOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
+    if (zoomIn)
+    {
+        state->setFOV(state->getFOV() / 1.1);
+        state->SetDirtyViewport();
+        state->ForceRequireRedraw();
+        state->Redraw();
+    }
+    else
+    {
+        state->setFOV(state->getFOV() * 1.1);
+        state->SetDirtyViewport();
+        state->ForceRequireRedraw();
+        state->Redraw();
+    };
+}
 void PanosphereOverviewCameraTool::MouseWheelEvent(wxMouseEvent &e)
 {
-    if (e.GetWheelRotation() != 0) {
-        ChangeZoomLevel(e.GetWheelRotation() > 0);
+    if (e.GetWheelRotation() != 0)
+    {
+        if (static_cast<PanosphereOverviewVisualizationState*>(helper->GetVisualizationStatePtr())->isInsideView())
+        {
+            ChangeFOV(e.GetWheelRotation() > 0);
+        }
+        else
+        {
+            ChangeZoomLevel(e.GetWheelRotation() > 0);
+        };
     }
 }
 
