@@ -255,7 +255,7 @@ PanoCommand::PanoCommand* AddImageOperation::GetInternalCommand(wxWindow* parent
             }
             else
             {
-                return new PanoCommand::wxAddImagesCmd(pano, files);
+                return new PanoCommand::wxAddImagesCmd(pano, files, m_preferredLensType);
             };
         };
     };
@@ -532,11 +532,6 @@ PanoCommand::PanoCommand* ChangeColorAnchorImageOperation::GetInternalCommand(wx
 {
     HuginBase::PanoramaOptions opt = pano.getOptions();
     opt.colorReferenceImage = *(images.begin());
-    // Set the color correction mode so that the anchor image is persisted
-    if (opt.colorCorrection == 0)
-    {
-        opt.colorCorrection = (HuginBase::PanoramaOptions::ColorCorrection) 1;
-    }
     return new PanoCommand::SetPanoOptionsCmd(pano, opt);
 };
 
