@@ -22,9 +22,9 @@
 *
 */
 
+#include "panoinc_WX.h"
 #include "PapywizardImport.h"
 
-#include "panoinc_WX.h"
 #include "hugin_utils/utils.h"
 #include <wx/xml/xml.h>
 #include <wx/msgdlg.h>
@@ -161,7 +161,13 @@ bool ParseShoot(wxXmlNode* root, PapywizardSettings& images)
             PapywizardSettings::PapywizardImage image;
             long longVal;
             wxString s;
-            // check id
+#ifdef PAPYWIZARD_USE_ID_CHECK
+            // according to the spec the id should be unique
+            // but not all programs write the id in this way
+            // e.g. PCPano is using the same id for each image in a bracket
+            // see https://bugs.launchpad.net/hugin/+bug/1840110
+            // so the check id code is disabled for now
+            // so activate the check again define PAPYWIZARD_USE_ID_CHECK 
             if (!child->GetAttribute(wxT("id"), &s))
             {
                 return false;
@@ -175,6 +181,10 @@ bool ParseShoot(wxXmlNode* root, PapywizardSettings& images)
                 return false;
             };
             image.id = longVal;
+#else
+            // instead simply store a continous id 
+            image.id = id;
+#endif
             ++id;
             // read bracket attribute
             if(!child->GetAttribute(wxT("bracket"), &s))
@@ -271,11 +281,13 @@ public:
     {
         wxXmlResource::Get()->LoadDialog(this, parent, wxT("papywizard_import_dialog"));
 #ifdef __WXMSW__
-        wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/hugin.ico"), wxBITMAP_TYPE_ICO);
+        wxIconBundle myIcons(huginApp::Get()->GetXRCPath() + wxT("data/hugin.ico"), wxBITMAP_TYPE_ICO);
+        SetIcons(myIcons);
 #else
         wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/hugin.png"), wxBITMAP_TYPE_PNG);
-#endif
         SetIcon(myIcon);
+#endif
+
         m_linkPos = XRCCTRL(*this, "papywizard_link_positions", wxCheckBox);
         m_cpfind = XRCCTRL(*this, "papywizard_cpfind", wxCheckBox);
         m_cpfindParams = XRCCTRL(*this, "papywizard_cpfind_parameters", wxTextCtrl);
@@ -448,10 +460,8 @@ bool ImportPapywizardFile(const wxString& filename, HuginBase::Panorama& pano)
             }
         };
         wxFileName scriptFileName(wxFileName::CreateTempFileName(tempDir + wxT("hp")));
-        std::ofstream script(scriptFileName.GetFullPath().mb_str(HUGIN_CONV_FILENAME));
-        script.exceptions(std::ofstream::eofbit | std::ofstream::failbit | std::ofstream::badbit);
-        pano.printPanoramaScript(script, pano.getOptimizeVector(), pano.getOptions(), images, false);
-        script.close();
+        const std::string scriptString(scriptFileName.GetFullPath().mb_str(HUGIN_CONV_FILENAME));
+        pano.WritePTOFile(scriptString, hugin_utils::getPathPrefix(scriptString));
         // build command queue
         const wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
         HuginQueue::CommandQueue* commands=new HuginQueue::CommandQueue();
