@@ -38,6 +38,7 @@
 #include "hugin/PreferencesDialog.h"
 #include "hugin/CPDetectorDialog.h"
 #include "hugin/MainFrame.h"
+#include "hugin/EditOutputIniDialog.h"
 #include "base_wx/huginConfig.h"
 
 // validators are working different somehow...
@@ -75,6 +76,8 @@ BEGIN_EVENT_TABLE(PreferencesDialog, wxDialog)
     EVT_CHECKBOX(XRCID("prefs_ft_RotationSearch"), PreferencesDialog::OnRotationCheckBox)
     EVT_CHECKBOX(XRCID("prefs_enblend_Custom"), PreferencesDialog::OnCustomEnblend)
     EVT_CHECKBOX(XRCID("prefs_enblend_enfuseCustom"), PreferencesDialog::OnCustomEnfuse)
+    EVT_CHECKBOX(XRCID("pref_ass_output"), PreferencesDialog::OnUserDefinedOutputOptionsCheckBox)
+    EVT_BUTTON(XRCID("pref_ass_change_output"), PreferencesDialog::OnChangeUserDefinedOutputOptions)
     EVT_BUTTON(XRCID("pref_cpdetector_new"), PreferencesDialog::OnCPDetectorAdd)
     EVT_BUTTON(XRCID("pref_cpdetector_edit"), PreferencesDialog::OnCPDetectorEdit)
     EVT_BUTTON(XRCID("pref_cpdetector_del"), PreferencesDialog::OnCPDetectorDelete)
@@ -683,6 +686,10 @@ void PreferencesDialog::UpdateDisplayData(int panel)
         MY_BOOL_VAL("prefs_celeste_auto", t);
         t = cfg->Read(wxT("/Assistant/AutoCPClean"), HUGIN_ASS_AUTO_CPCLEAN) == 1;
         MY_BOOL_VAL("prefs_auto_cpclean", t);
+        t = cfg->Read(wxT("/Assistant/UserDefinedOutputOption"), 0l) == 1;
+        MY_BOOL_VAL("pref_ass_output", t);
+        wxCommandEvent dummy;
+        OnUserDefinedOutputOptionsCheckBox(dummy);
     }
     // Fine tune settings
 
@@ -901,6 +908,7 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent& e)
             cfg->Write(wxT("/Assistant/Linefind"), HUGIN_ASS_LINEFIND);
             cfg->Write(wxT("/Celeste/Auto"), HUGIN_CELESTE_AUTO);
             cfg->Write(wxT("/Assistant/AutoCPClean"), HUGIN_ASS_AUTO_CPCLEAN);
+            cfg->Write(wxT("/Assistant/UserDefinedOutputOption"), 0l);
         }
         if (noteb->GetSelection() == 3)
         {
@@ -1000,6 +1008,7 @@ void PreferencesDialog::UpdateConfigData()
     cfg->Write(wxT("/Assistant/Linefind"), MY_G_BOOL_VAL("prefs_ass_linefind"));
     cfg->Write(wxT("/Celeste/Auto"), MY_G_BOOL_VAL("prefs_celeste_auto"));
     cfg->Write(wxT("/Assistant/AutoCPClean"), MY_G_BOOL_VAL("prefs_auto_cpclean"));
+    cfg->Write(wxT("/Assistant/UserDefinedOutputOption"), MY_G_BOOL_VAL("pref_ass_output"));
 
     // hdr display
     cfg->Write(wxT("/ImageCache/Mapping"),MY_G_CHOICE_VAL("prefs_misc_hdr_mapping"));
@@ -1340,3 +1349,15 @@ void PreferencesDialog::OnUpdateOutputFilename(wxCommandEvent& e)
     );
 };
 
+void PreferencesDialog::OnUserDefinedOutputOptionsCheckBox(wxCommandEvent& e)
+{
+    //enable/disable button related to user defined output options of assistant
+    XRCCTRL(*this, "pref_ass_change_output", wxButton)->Enable(XRCCTRL(*this, "pref_ass_output", wxCheckBox)->IsChecked());
+}
+
+void PreferencesDialog::OnChangeUserDefinedOutputOptions(wxCommandEvent& e)
+{
+    // show dialog to change user defined output options of assistant
+    EditOutputIniDialog dlg(this);
+    dlg.ShowModal();
+}
