@@ -80,6 +80,8 @@ protected:
     void OnCPDetectorMoveDown(wxCommandEvent & e);
     void OnCPDetectorDefault(wxCommandEvent & e);
     void OnCPDetectorListDblClick(wxCommandEvent & e);
+    void OnUserDefinedOutputOptionsCheckBox(wxCommandEvent & e);
+    void OnChangeUserDefinedOutputOptions(wxCommandEvent & e);
     /** event handler for loading cp detector settings */
     void OnCPDetectorLoad(wxCommandEvent & e);
     /** event handler for saving cp detector settings */
