@@ -26,7 +26,7 @@
 #define _PREVIEWCOLORPICKERTOOL_H
 
 #include "Tool.h"
-#include "hugin_utils/utils.h"
+#include "base_wx/wxutils.h"
 
 /** The PreviewColorPickerTool allows to select a region in the panorama which should be grey.
  *  In the selected region it calculates the new red multiplier and blue multiplier to get
@@ -37,7 +37,7 @@ class PreviewColorPickerTool : public Tool
 {
 public:
     /** constructor */
-    PreviewColorPickerTool(ToolHelper *helper):Tool(helper) {};
+    explicit PreviewColorPickerTool(ToolHelper *helper):Tool(helper), m_red(0.0), m_blue(0.0), m_count(0) {};
     void Activate();
     /** process mouse button events */
     void MouseButtonEvent(wxMouseEvent &e);
