@@ -24,13 +24,17 @@
 #endif
 #include "PreviewDifferenceTool.h"
 #include "hugin_config.h"
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#include <epoxy/gl.h>
+#else
 #include <GL/glew.h>
-#include <wx/platform.h>
 #ifdef __WXMAC__
 #include <OpenGL/gl.h>
 #else
 #include <GL/gl.h>
 #endif
+#endif
+#include <wx/platform.h>
 
 // This is the number of times to double the result of the difference. It should
 // be between 0 and 7. Note that with  values > 0 no extra colours are used
@@ -46,10 +50,21 @@ PreviewDifferenceTool::PreviewDifferenceTool(ToolHelper *helper)
 /** call this function only after OpenGL context was created */
 bool PreviewDifferenceTool::CheckOpenGLCanDifference()
 {
+#if defined HAVE_EPOXY && HAVE_EPOXY
+    if (epoxy_has_gl_extension("GL_ARB_imaging"))
+    {
+        return true;
+    };
+    if ((glBlendEquation != NULL) && (epoxy_has_gl_extension("GL_EXT_blend_subtract")))
+    {
+        return true;
+    };
+#else
     if(GLEW_ARB_imaging)
         return true;
     if((glBlendEquation!=NULL) && (GLEW_EXT_blend_subtract))
         return true;
+#endif
     return false;
 }
 
