@@ -546,15 +546,9 @@ void PreviewFrame::panoramaImagesChanged(HuginBase::Panorama &pano, const HuginB
 //                wxImage * bmp = new wxImage(sz.GetWidth(), sz.GetHeight());
                 wxToggleButton * but = new wxToggleButton(m_ButtonPanel,
                                                           ID_TOGGLE_BUT + *it,
-                                                          wxString::Format(wxT("%d"),*it),
+                                                          wxString::Format(wxT(" %d "),*it),
                                                           wxDefaultPosition, wxDefaultSize,
                                                           wxBU_EXACTFIT);
-                wxSize sz = but->GetSize();
-//                but->SetSize(res.GetWidth(),sz.GetHeight());
-                // HACK.. set fixed width. that should work
-                // better than all that stupid dialogunit stuff, that
-                // breaks on wxWin 2.5
-                but->SetSize(20, sz.GetHeight());
                 but->SetValue(true);
                 m_ButtonSizer->Add(but,
                                    0,
