@@ -32,7 +32,11 @@
 #include <wx/platform.h>
 
 //multitexture feature requires glew on some systems
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#include <epoxy/gl.h>
+#else
 #include <GL/glew.h>
+#endif
 
 #ifdef __WXMAC__
 #include <OpenGL/gl.h>
