@@ -40,7 +40,7 @@
 
 #include <string>
 #include <map>
-#include "hugin_utils/shared_ptr.h"
+#include <memory>
 #include <huginapp/ImageCache.h>
 #include "panodata/Panorama.h"
 
@@ -85,7 +85,7 @@ protected:
     class TextureInfo
     {
     public:
-        TextureInfo(ViewState *new_view_state);
+        explicit TextureInfo(ViewState *new_view_state);
         // specify log2(width) and log2(height) for the new texture's size.
         // this is the size of mip level 0, which may or may not be defined.
         TextureInfo(ViewState *new_view_state, unsigned int width_p, unsigned int height_p);
@@ -164,7 +164,7 @@ protected:
     };
     // we map filenames to TexturesInfos, so we can keep track of
     // images' textures when the numbers change.
-    typedef std::map<TextureKey, sharedPtrNamespace::shared_ptr<TextureInfo> > TexturesMap;
+    typedef std::map<TextureKey, std::shared_ptr<TextureInfo> > TexturesMap;
     TexturesMap textures;
     // Our pixel budget for all textures.
     unsigned int GetMaxTotalTexels();
