@@ -16,8 +16,8 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -81,14 +81,10 @@
 
 // Exiftool
 #define HUGIN_USE_EXIFTOOL                    1l
-#ifdef EXIFTOOL_GPANO_SUPPORT
 #define HUGIN_EXIFTOOL_CREATE_GPANO           1l
-#else
-#define HUGIN_EXIFTOOL_CREATE_GPANO           0l
-#endif
 
 // Program defaults
-#if defined WIN32
+#if defined _WIN32
 
 #define HUGIN_PT_SCRIPTFILE                   "PT_script.txt"
 
@@ -168,6 +164,9 @@
 # define HUGIN_JPEG_QUALITY                  90l
 # define HUGIN_HDR_OUTPUT_FORMAT              0l
 
+// default blender
+#define HUGIN_DEFAULT_BLENDER  HuginBase::PanoramaOptions::ENBLEND_BLEND
+
 // hdrmerge defaults
 #define HUGIN_HDRMERGE_ARGS                  "-m avg -c"
 
@@ -183,7 +182,6 @@
 // processor
 #define HUGIN_PROCESSOR_GUI             0l    // first in the list in the xrc file
 #define HUGIN_PROCESSOR_START           1l    // boolean
-#define HUGIN_PROCESSOR_PARALLEL        0l    // boolean
 #define HUGIN_PROCESSOR_OVERWRITE       0l    // boolean
 #define HUGIN_PROCESSOR_VERBOSE         1l    // boolean
 
