@@ -48,7 +48,7 @@
 #include "base_wx/huginConfig.h"
 #include "base_wx/wxPlatform.h"
 #include <wx/utils.h>
-#ifdef __WXMSW__
+#if defined __WXMSW__ || defined UNIX_SELF_CONTAINED_BUNDLE
 #include <wx/stdpaths.h>
 #endif
 
@@ -169,7 +169,7 @@ wxString GetProgPath(wxString progName)
     if(!bundled.IsEmpty())
         return bundled;
 #else 
-#ifdef __WXMSW__
+#if defined __WXMSW__ || defined UNIX_SELF_CONTAINED_BUNDLE
     wxFileName prog(progName);
     if(prog.IsAbsolute())
     {
@@ -203,7 +203,7 @@ bool CanStartProg(wxString progName,wxWindow* parent)
     else
     {
         wxPathList pathlist;
-#ifdef __WXMSW__
+#if defined __WXMSW__ || defined UNIX_SELF_CONTAINED_BUNDLE
         const wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
         pathlist.Add(exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR));
 #endif
@@ -224,6 +224,19 @@ bool CanStartProg(wxString progName,wxWindow* parent)
     return canStart;
 };
 
+wxString GetCheckedTempDir()
+{
+    wxString tempDir = wxConfigBase::Get()->Read(wxT("tempDir"), wxT(""));
+    if (!tempDir.IsEmpty())
+    {
+        if (tempDir.Last() != wxFileName::GetPathSeparator())
+        {
+            tempDir.Append(wxFileName::GetPathSeparator());
+        };
+    };
+    return tempDir;
+};
+
 HuginBase::CPVector AutoCtrlPointCreator::automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, wxWindow *parent)
 {
@@ -310,7 +323,7 @@ void AutoCtrlPointCreator::Cleanup(CPDetectorSetting &setting, HuginBase::Panora
 {
     if(setting.IsTwoStepDetector())
     {
-        if(keyFiles.size()>0)
+        if(!keyFiles.empty())
         {
             for(unsigned int i=0;i<keyFiles.size();i++)
             {
@@ -338,8 +351,8 @@ void AutoCtrlPointCreator::Cleanup(CPDetectorSetting &setting, HuginBase::Panora
             return;
         };
     
-        wxString ptoinfile_name = wxFileName::CreateTempFileName(wxT("ap_inproj"));
-        cleanupArgs.Replace(wxT("%s"), ptoinfile_name);
+        wxString ptoinfile_name = wxFileName::CreateTempFileName(GetCheckedTempDir() + ("ap_inproj"));
+        cleanupArgs.Replace(wxT("%s"), hugin_utils::wxQuoteFilename(ptoinfile_name));
         std::ofstream ptoinstream(ptoinfile_name.mb_str(wxConvFile));
         pano.printPanoramaScript(ptoinstream, pano.getOptimizeVector(), pano.getOptions(), imgs, false);
 
@@ -355,16 +368,26 @@ void AutoCtrlPointCreator::Cleanup(CPDetectorSetting &setting, HuginBase::Panora
         };
     };
 };
-        
+
 HuginBase::CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                                      int nFeatures, int & ret_value, wxWindow *parent)
 {
     HuginBase::CPVector cps;
-    if (imgs.size() == 0) {
+    if (imgs.empty()) {
         return cps;
     }
     // create suitable command line..
-    wxString autopanoExe = GetProgPath(setting.GetProg());
+    const wxString autopanoExe = GetProgPath(setting.GetProg());
+    // special cases
+    // geocpset needs other control points to link only unlinked images
+    // linefind needs other control points to correctly ignore nadir/zenit near images
+    //   (but only when all images are selected, ignore this limitation when user
+    //    selected certain images
+    // cpfind with prealigned setting
+    const bool detectorNeedsOtherCp = (autopanoExe.Find("geocpset") != wxNOT_FOUND) || 
+        (autopanoExe.Find("linefind") != wxNOT_FOUND && pano.getNrOfImages()==imgs.size()) ||
+        (autopanoExe.Find("cpfind") != wxNOT_FOUND && setting.GetArgs().Find("--prealigned") != wxNOT_FOUND);
+    size_t oldCpsSize = -1;
     if(setting.IsTwoStepDetector())
     {
         std::vector<wxString> keyFiles(pano.getNrOfImages());
@@ -374,9 +397,19 @@ HuginBase::CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, HuginBas
     };
     wxString autopanoArgs = setting.GetArgs();
     
+    // generate hash for all old cps
+    std::set<std::string> cpsHash;
+    {
+        const HuginBase::CPVector& cps = pano.getCtrlPoints();
+        for (auto& cp : cps)
+        {
+            cpsHash.insert(cp.getCPString());
+        };
+    };
+
     // TODO: create a secure temporary filename here
-    wxString ptofile = wxFileName::CreateTempFileName(wxT("ap_res"));
-    autopanoArgs.Replace(wxT("%o"), ptofile);
+    wxString ptofile = wxFileName::CreateTempFileName(GetCheckedTempDir() + wxT("ap_res"));
+    autopanoArgs.Replace(wxT("%o"), hugin_utils::wxQuoteFilename(ptofile));
     wxString tmp;
     tmp.Printf(wxT("%d"), nFeatures);
     autopanoArgs.Replace(wxT("%p"), tmp);
@@ -407,9 +440,9 @@ HuginBase::CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, HuginBas
     wxString namefile_name;
     if (use_namefile) {
         // create temporary file with image names.
-        namefile_name = wxFileName::CreateTempFileName(wxT("ap_imgnames"), &namefile);
+        namefile_name = wxFileName::CreateTempFileName(GetCheckedTempDir() + wxT("ap_imgnames"), &namefile);
         DEBUG_DEBUG("before replace %namefile: " << autopanoArgs.mb_str(wxConvLocal));
-        autopanoArgs.Replace(wxT("%namefile"), namefile_name);
+        autopanoArgs.Replace(wxT("%namefile"), hugin_utils::wxQuoteFilename(namefile_name));
         DEBUG_DEBUG("after replace %namefile: " << autopanoArgs.mb_str(wxConvLocal));
         for (HuginBase::UIntSet::const_iterator it = imgs.begin(); it != imgs.end(); ++it)
         {
@@ -432,16 +465,27 @@ HuginBase::CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, HuginBas
     wxString ptoinfile_name;
     if (use_inputscript) {
         wxFile ptoinfile;
-        ptoinfile_name = wxFileName::CreateTempFileName(wxT("ap_inproj"));
-        autopanoArgs.Replace(wxT("%s"), ptoinfile_name);
+        ptoinfile_name = wxFileName::CreateTempFileName(GetCheckedTempDir() + ("ap_inproj"));
+        autopanoArgs.Replace(wxT("%s"), hugin_utils::wxQuoteFilename(ptoinfile_name));
 
         std::ofstream ptoinstream(ptoinfile_name.mb_str(wxConvFile));
-        //delete all existing control points in temp project
-        //otherwise the existing control points will be loaded again
-        HuginBase::Panorama tempPano = pano.duplicate();
-        HuginBase::CPVector emptyCPV;
-        tempPano.setCtrlPoints(emptyCPV);
-        tempPano.printPanoramaScript(ptoinstream, tempPano.getOptimizeVector(), tempPano.getOptions(), imgs, false);
+        // create a temporary project with only the selected images
+        HuginBase::Panorama tempPano = pano.getSubset(imgs);
+        if (detectorNeedsOtherCp)
+        {
+            // when the cp generator needs the other cps to work
+            // store the number of cps in the input project
+            oldCpsSize = tempPano.getNrOfCtrlPoints();
+        }
+        else
+        {
+            // in all other cases delete all cps
+            HuginBase::CPVector emptyCPV;
+            tempPano.setCtrlPoints(emptyCPV);
+        };
+        HuginBase::UIntSet tempImgSet;
+        fill_set(tempImgSet, 0, tempPano.getNrOfImages() - 1);
+        tempPano.printPanoramaScript(ptoinstream, tempPano.getOptimizeVector(), tempPano.getOptions(), tempImgSet, false);
     }
 
 #ifdef __WXMSW__
@@ -486,6 +530,24 @@ HuginBase::CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, HuginBas
 
     // read and update control points
     cps = readUpdatedControlPoints((const char*)ptofile.mb_str(HUGIN_CONV_FILENAME), pano, imgs, !use_inputscript);
+    if (detectorNeedsOtherCp && oldCpsSize >= 0)
+    {
+        // for geocpset/cpfind --prealigned remove all old cps from the vector
+        cps.erase(cps.begin(), cps.begin() + oldCpsSize);
+    };
+    // now check that the new cp are unique
+    if (!cps.empty())
+    {
+        size_t i = cps.size() - 1;
+        for (auto it = cps.rbegin(); it != cps.rend(); ++it, --i)
+        {
+            if (set_contains(cpsHash, it->getCPString()))
+            {
+                // remove duplicates
+                cps.erase(cps.begin() + i);
+            };
+        };
+    };
 
     if (namefile_name != wxString(wxT(""))) {
         namefile.Close();
@@ -507,7 +569,7 @@ HuginBase::CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, HuginBas
                            int nFeatures, std::vector<wxString> &keyFiles, int & ret_value, wxWindow *parent)
 {
     HuginBase::CPVector cps;
-    if (imgs.size() == 0) 
+    if (imgs.empty()) 
     {
         return cps;
     }
@@ -518,10 +580,6 @@ HuginBase::CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, HuginBas
     wxString generateKeysArgs=setting.GetArgs();
     wxString matcherArgs = setting.GetArgsMatcher();
     
-    wxString tempDir= wxConfigBase::Get()->Read(wxT("tempDir"),wxT(""));
-    if(!tempDir.IsEmpty())
-        if(tempDir.Last()!=wxFileName::GetPathSeparator())
-            tempDir.Append(wxFileName::GetPathSeparator());
     //check arguments
     if(generateKeysArgs.Find(wxT("%i"))==wxNOT_FOUND || generateKeysArgs.Find(wxT("%k"))==wxNOT_FOUND)
     {
@@ -537,6 +595,7 @@ HuginBase::CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, HuginBas
     };
 
     ret_value=0;
+    const wxString tempDir = GetCheckedTempDir();
     for (HuginBase::UIntSet::const_iterator img = imgs.begin(); img != imgs.end(); ++img)
     {
         if(keyFiles[*img].IsEmpty())
@@ -580,8 +639,8 @@ HuginBase::CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, HuginBas
     };
 
     // TODO: create a secure temporary filename here
-    wxString ptofile = wxFileName::CreateTempFileName(wxT("ap_res"));
-    matcherArgs.Replace(wxT("%o"), ptofile);
+    wxString ptofile = wxFileName::CreateTempFileName(GetCheckedTempDir() + wxT("ap_res"));
+    matcherArgs.Replace(wxT("%o"), hugin_utils::wxQuoteFilename(ptofile));
     wxString tmp;
     tmp.Printf(wxT("%d"), nFeatures);
     matcherArgs.Replace(wxT("%p"), tmp);
@@ -669,10 +728,10 @@ HuginBase::CPVector AutoPanoKolor::automatch(CPDetectorSetting &setting, HuginBa
         imgFiles.append(" ").append(hugin_utils::quoteFilename(pano.getImage(*it).getFilename()));
     }
 
-    wxString ptofilepath = wxFileName::CreateTempFileName(wxT("ap_res"));
+    wxString ptofilepath = wxFileName::CreateTempFileName(GetCheckedTempDir() + wxT("ap_res"));
     wxFileName ptofn(ptofilepath);
     wxString ptofile = ptofn.GetFullName();
-    autopanoArgs.Replace(wxT("%o"), ptofile);
+    autopanoArgs.Replace(wxT("%o"), hugin_utils::wxQuoteFilename(ptofile));
     wxString tmp;
     tmp.Printf(wxT("%d"), nFeatures);
     autopanoArgs.Replace(wxT("%p"), tmp);
@@ -776,7 +835,7 @@ HuginBase::CPVector AutoPanoSiftStack::automatch(CPDetectorSetting &setting, Hug
                                      int nFeatures, int & ret_value, wxWindow *parent)
 {
     HuginBase::CPVector cps;
-    if (imgs.size() == 0) {
+    if (imgs.empty()) {
         return cps;
     };
     std::vector<stack_img> stack_images;
@@ -847,7 +906,7 @@ HuginBase::CPVector AutoPanoSiftStack::automatch(CPDetectorSetting &setting, Hug
             {
                 AutoPanoSift matcher;
                 HuginBase::CPVector new_cps = matcher.automatch(stack_setting, pano, images_stack, nFeatures, ret_value, parent);
-                if(new_cps.size()>0)
+                if(!new_cps.empty())
                     AddControlPointsWithCheck(cps,new_cps);
                 if(ret_value!=0)
                     return cps;
@@ -885,7 +944,7 @@ HuginBase::CPVector AutoPanoSiftMultiRow::automatch(CPDetectorSetting &setting,
             new_cps=matcher.automatch(setting, pano, ImagePair, nFeatures, keyFiles, ret_value, parent);
         else
             new_cps=matcher.automatch(setting, pano, ImagePair, nFeatures, ret_value, parent);
-        if(new_cps.size()>0)
+        if(!new_cps.empty())
             AddControlPointsWithCheck(cps,new_cps);
         if(ret_value!=0)
         {
@@ -919,7 +978,7 @@ HuginBase::CPVector AutoPanoSiftMultiRow::automatch(CPDetectorSetting &setting,
             new_cps=matcher.automatch(setting, optPano, ImagesGroups, nFeatures, keyFiles, ret_value, parent);
         else
             new_cps=matcher.automatch(setting, optPano, ImagesGroups, nFeatures, ret_value, parent);
-        if(new_cps.size()>0)
+        if(!new_cps.empty())
             AddControlPointsWithCheck(cps,new_cps,&optPano);
         if(ret_value!=0)
         {
@@ -1002,7 +1061,7 @@ HuginBase::CPVector AutoPanoSiftMultiRow::automatch(CPDetectorSetting &setting,
             new_cps=matcher.automatch(newSetting, optPano, imgs, nFeatures, keyFiles, ret_value, parent);
         else
             new_cps=matcher.automatch(newSetting, optPano, imgs, nFeatures, ret_value, parent);
-        if(new_cps.size()>0)
+        if(!new_cps.empty())
             AddControlPointsWithCheck(cps,new_cps);
     };
     Cleanup(setting, pano, imgs, keyFiles, parent);
@@ -1013,7 +1072,7 @@ HuginBase::CPVector AutoPanoSiftMultiRowStack::automatch(CPDetectorSetting &sett
                                      int nFeatures, int & ret_value, wxWindow *parent)
 {
     HuginBase::CPVector cps;
-    if (imgs.size() == 0) {
+    if (imgs.empty()) {
         return cps;
     };
     std::vector<stack_img> stack_images;
@@ -1076,7 +1135,7 @@ HuginBase::CPVector AutoPanoSiftMultiRowStack::automatch(CPDetectorSetting &sett
             {
                 AutoPanoSift matcher;
                 HuginBase::CPVector new_cps = matcher.automatch(stack_setting, pano, images_stack, nFeatures, ret_value, parent);
-                if(new_cps.size()>0)
+                if(!new_cps.empty())
                     AddControlPointsWithCheck(cps,new_cps);
                 if(ret_value!=0)
                 {
@@ -1093,13 +1152,13 @@ HuginBase::CPVector AutoPanoSiftMultiRowStack::automatch(CPDetectorSetting &sett
         HuginBase::UIntSet allImgs;
         fill_set(allImgs, 0, pano.getNrOfImages()-1);
         HuginBase::Panorama newPano = pano.getSubset(allImgs);
-        if(cps.size()>0)
+        if(!cps.empty())
             for (HuginBase::CPVector::const_iterator it = cps.begin(); it != cps.end(); ++it)
                 newPano.addCtrlPoint(*it);
 
         AutoPanoSiftMultiRow matcher;
         HuginBase::CPVector new_cps = matcher.automatch(setting, newPano, images_layer, nFeatures, ret_value, parent);
-        if(new_cps.size()>0)
+        if(!new_cps.empty())
             AddControlPointsWithCheck(cps,new_cps);
     };
     return cps;
@@ -1166,7 +1225,7 @@ HuginBase::CPVector AutoPanoSiftPreAlign::automatch(CPDetectorSetting &setting,
             new_cps=matcher.automatch(setting, pano, images, nFeatures, keyFiles, ret_value, parent);
         else
             new_cps=matcher.automatch(setting, pano, images, nFeatures, ret_value, parent);
-        if(new_cps.size()>0)
+        if(!new_cps.empty())
             AddControlPointsWithCheck(cps,new_cps);
         if(ret_value!=0)
         {
