@@ -18,8 +18,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -67,9 +67,7 @@
 // ===== Hugin specific with no dependencies to WX
 // =====
 
-#include "PT/Panorama.h"
-#include "PT/PanoramaMemento.h"
-#include "PT/PanoCommand.h"
+#include "panodata/Panorama.h"
 
 #endif
 
