@@ -40,11 +40,12 @@ FailedProjectsDialog::FailedProjectsDialog(wxWindow* parent,Batch* batch,wxStrin
     wxXmlResource::Get()->LoadDialog(this,parent,wxT("failed_project_dialog"));
 
 #ifdef __WXMSW__
-    wxIcon myIcon(xrcPrefix+ wxT("data/ptbatcher.ico"),wxBITMAP_TYPE_ICO);
+    wxIconBundle myIcons(xrcPrefix+ wxT("data/ptbatcher.ico"),wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
 #else
     wxIcon myIcon(xrcPrefix + wxT("data/ptbatcher.png"),wxBITMAP_TYPE_PNG);
-#endif
     SetIcon(myIcon);
+#endif
     m_batch=batch;
 
     m_list=XRCCTRL(*this,"failed_list",wxListBox);
