@@ -53,7 +53,6 @@ wxIMPLEMENT_APP(PTBatcherGUI);
 
 BEGIN_EVENT_TABLE(PTBatcherGUI, wxApp)
     EVT_LIST_ITEM_ACTIVATED(XRCID("project_listbox"),PTBatcherGUI::OnItemActivated)
-    EVT_KEY_DOWN(PTBatcherGUI::OnKeyDown)
 END_EVENT_TABLE()
 
 bool PTBatcherGUI::OnInit()
@@ -160,6 +159,7 @@ bool PTBatcherGUI::OnInit()
         { wxCMD_LINE_SWITCH, "s", "shutdown",  "shutdown computer after batch is complete" },
         { wxCMD_LINE_SWITCH, "v", "verbose",  "show verbose output when processing projects" },
         { wxCMD_LINE_SWITCH, "a", "assistant", "run the assistant on the given projects" },
+        { wxCMD_LINE_OPTION, "u", "user-defined", "use the given user defined sequence" },
         {
             wxCMD_LINE_PARAM,  NULL, NULL, "stitch_project.pto [output prefix]|assistant_project.pto",
             wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL + wxCMD_LINE_PARAM_MULTIPLE
@@ -251,6 +251,8 @@ bool PTBatcherGUI::OnInit()
     if (parser.Found(wxT("a")))
     {
         //added assistant files
+        wxString userDefined;
+        parser.Found(wxT("u"), &userDefined);
         while (parser.GetParamCount() > count)
         {
             wxString param = parser.GetParam(count);
@@ -264,11 +266,15 @@ bool PTBatcherGUI::OnInit()
                 {
                     if (IsFirstInstance)
                     {
-                        m_frame->AddToList(name.GetFullPath(), Project::DETECTING);
+                        m_frame->AddToList(name.GetFullPath(), Project::DETECTING, userDefined);
                     }
                     else
                     {
                         conn->Request(wxT("D ") + name.GetFullPath());
+                        if (!userDefined.IsEmpty())
+                        {
+                            conn->Request(wxT("U ") + userDefined);
+                        };
                     };
                 };
             };
@@ -277,6 +283,8 @@ bool PTBatcherGUI::OnInit()
     else
     {
         bool projectSpecified = false;
+        wxString userDefined;
+        parser.Found(wxT("u"), &userDefined);
         //we collect all parameters - all project files <and their output prefixes>
         while (parser.GetParamCount() > count)
         {
@@ -288,11 +296,15 @@ bool PTBatcherGUI::OnInit()
                 name.MakeAbsolute();
                 if (IsFirstInstance)
                 {
-                    m_frame->AddToList(name.GetFullPath());
+                    m_frame->AddToList(name.GetFullPath(), Project::STITCHING, userDefined);
                 }
                 else
                 {
                     conn->Request(wxT("A ") + name.GetFullPath());
+                    if (!userDefined.IsEmpty())
+                    {
+                        conn->Request(wxT("U ") + userDefined);
+                    };
                 }
                 projectSpecified = true;
             }
@@ -309,7 +321,7 @@ bool PTBatcherGUI::OnInit()
                     else
                     {
                         conn->Request(wxT("P ") + fn.GetFullPath());
-                    }
+                    };
                     projectSpecified = false;
                 }
                 else
@@ -329,7 +341,7 @@ bool PTBatcherGUI::OnInit()
                         else
                         {
                             conn->Request(wxT("P ") + fn.GetFullPath());
-                        }
+                        };
                         projectSpecified = false;
                     }
                     else //if parameter has a different extension we presume it is a new script file
@@ -337,11 +349,15 @@ bool PTBatcherGUI::OnInit()
                         //we add the new project
                         if (IsFirstInstance)
                         {
-                            m_frame->AddToList(fn.GetFullPath());
+                            m_frame->AddToList(fn.GetFullPath(), Project::STITCHING, userDefined);
                         }
                         else
                         {
                             conn->Request(wxT("A ") + fn.GetFullPath());
+                            if (!userDefined.IsEmpty())
+                            {
+                                conn->Request(wxT("U ") + userDefined);
+                            };
                         }
                         projectSpecified = true;
                     }
@@ -448,27 +464,6 @@ void PTBatcherGUI::OnItemActivated(wxListEvent& event)
     m_frame->OnButtonOpenWithHugin(dummy);
 }
 
-void PTBatcherGUI::OnKeyDown(wxKeyEvent& event)
-{
-    wxCommandEvent dummy;
-    switch(event.GetKeyCode())
-    {
-        case WXK_DELETE:
-            m_frame->OnButtonRemoveFromList(dummy);
-            break;
-        case WXK_INSERT:
-            m_frame->OnButtonAddToStitchingQueue(dummy);
-            break;
-        case WXK_ESCAPE:
-            m_frame->OnButtonCancel(dummy);
-            break;
-        default:
-            event.Skip();
-            break;
-    }
-
-}
-
 #ifdef __WXMAC__
 // wx calls this method when the app gets "Open files" AppleEvent
 void PTBatcherGUI::MacOpenFiles(const wxArrayString &fileNames) 
@@ -495,7 +490,7 @@ const void* BatchIPCConnection::OnRequest(const wxString& topic, const wxString&
     };
     if(item.Left(1)==wxT("D"))
     {
-        MyBatchFrame->AddToList(item.Mid(2),Project::DETECTING);
+        MyBatchFrame->AddToList(item.Mid(2), Project::DETECTING);
         return wxEmptyString;
     };
     if(item.Left(1)==wxT("P"))
@@ -503,6 +498,11 @@ const void* BatchIPCConnection::OnRequest(const wxString& topic, const wxString&
         MyBatchFrame->ChangePrefix(-1,item.Mid(2));
         return wxEmptyString;
     };
+    if (item.Left(1) == wxT("U"))
+    {
+        MyBatchFrame->ChangeUserDefined(-1, item.Mid(2));
+        return wxEmptyString;
+    };
     wxCommandEvent event;
     event.SetInt(1);
 #if !defined __WXMAC__ && !defined __WXOSX_COCOA__
