@@ -34,7 +34,7 @@
 
 long Project::idGenerator=1;
 
-Project::Project(wxString pth,wxString pfx, Project::Target newTarget)
+Project::Project(wxString pth,wxString pfx, wxString newUserDefinedSequence, Project::Target newTarget)
 {
     id = Project::idGenerator;
     Project::idGenerator++;
@@ -45,6 +45,7 @@ Project::Project(wxString pth,wxString pfx, Project::Target newTarget)
     {
         file.GetTimes(NULL,&modDate,NULL);
     }
+    userDefindSequence = newUserDefinedSequence;
     isAligned = true;
     options = ReadOptions(pth);
     skip = false;
