@@ -57,10 +57,18 @@
 #include <libgen.h>       /* dirname */
 #endif
 
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#include <epoxy/gl.h>
+#ifdef _WIN32
+#include <epoxy/wgl.h>
+#endif
+#else
 #include <GL/glew.h>
 #ifdef _WIN32
 #include <GL/wglew.h>
-#elif defined __APPLE__
+#endif
+#endif
+#if defined __APPLE__
   #include <GLUT/glut.h>
 #endif
 
@@ -400,7 +408,28 @@ void EnforceExtension(std::string& filename, const std::string& defaultExtension
     {
         filename = stripExtension(filename) + "." + defaultExtension;
     };
-};
+}
+
+std::string GetOutputFilename(const std::string& out, const std::string& in, const std::string& suffix)
+{
+    if (out.empty())
+    {
+        const std::string extension = getExtension(in);
+        if (extension.empty())
+        {
+            return in + "_" + suffix;
+        }
+        else
+        {
+            return in.substr(0, in.length() - extension.length() - 1).append("_" + suffix + "." + extension);
+        };
+    }
+    else
+    {
+        return out;
+    };
+}
+
 
 std::string GetDataDir()
 {
@@ -584,6 +613,9 @@ bool CreateContext(int *argcp, char **argv)
     {
         return false;
     };
+#if defined HAVE_EPOXY && HAVE_EPOXY
+    epoxy_handle_external_wglMakeCurrent();
+#endif
     return true;
 }
 
@@ -592,6 +624,9 @@ void DestroyContext()
     if (context.renderingContext != NULL)
     {
         wglMakeCurrent(NULL, NULL);
+#if defined HAVE_EPOXY && HAVE_EPOXY
+        epoxy_handle_external_wglMakeCurrent();
+#endif
         wglDeleteContext(context.renderingContext);
     }
     if (context.window != NULL && context.dc != NULL)
@@ -628,7 +663,11 @@ void DestroyContext()
 
 #else
 #if defined HAVE_EGL && HAVE_EGL
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#include <epoxy/egl.h>
+#else
 #include <EGL/egl.h>
+#endif
 
 struct ContextSettings
 {
@@ -714,7 +753,11 @@ void DestroyContext()
 #else
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#include <epoxy/glx.h>
+#else
 #include <GL/glx.h>
+#endif
 
 struct ContextSettings
 {
@@ -811,6 +854,17 @@ bool initGPU(int *argcp, char **argv)
     {
         return false;
     };
+    std::cout << hugin_utils::stripPath(argv[0]) << ": using graphics card: " << glGetString(GL_VENDOR) << " " << glGetString(GL_RENDERER) << std::endl;
+#if defined HAVE_EPOXY && HAVE_EPOXY
+    const GLboolean has_arb_fragment_shader = epoxy_has_gl_extension("GL_ARB_fragment_shader");
+    const GLboolean has_arb_vertex_shader = epoxy_has_gl_extension("GL_ARB_vertex_shader");
+    const GLboolean has_arb_shader_objects = epoxy_has_gl_extension("GL_ARB_shader_objects");
+    const GLboolean has_arb_shading_language = epoxy_has_gl_extension("GL_ARB_shading_language_100");
+    const GLboolean has_ext_framebuffer = epoxy_has_gl_extension("GL_EXT_framebuffer_object");
+    const GLboolean has_arb_texture_rectangle = epoxy_has_gl_extension("GL_ARB_texture_rectangle");
+    const GLboolean has_arb_texture_border_clamp = epoxy_has_gl_extension("GL_ARB_texture_border_clamp");
+    const GLboolean has_arb_texture_float = epoxy_has_gl_extension("GL_ARB_texture_float");
+#else
     int err = glewInit();
     if (err != GLEW_OK)
     {
@@ -821,8 +875,6 @@ bool initGPU(int *argcp, char **argv)
         return false;
     }
 
-    std::cout << hugin_utils::stripPath(argv[0]) << ": using graphics card: " << glGetString(GL_VENDOR) << " " << glGetString(GL_RENDERER) << std::endl;
-
     const GLboolean has_arb_fragment_shader = glewGetExtension("GL_ARB_fragment_shader");
     const GLboolean has_arb_vertex_shader = glewGetExtension("GL_ARB_vertex_shader");
     const GLboolean has_arb_shader_objects = glewGetExtension("GL_ARB_shader_objects");
@@ -831,6 +883,7 @@ bool initGPU(int *argcp, char **argv)
     const GLboolean has_arb_texture_rectangle = glewGetExtension("GL_ARB_texture_rectangle");
     const GLboolean has_arb_texture_border_clamp = glewGetExtension("GL_ARB_texture_border_clamp");
     const GLboolean has_arb_texture_float = glewGetExtension("GL_ARB_texture_float");
+#endif
 
     if (!(has_arb_fragment_shader && has_arb_vertex_shader && has_arb_shader_objects && has_arb_shading_language && has_ext_framebuffer && has_arb_texture_rectangle && has_arb_texture_border_clamp && has_arb_texture_float)) {
         const char * msg[] = {"false", "true"};
