@@ -563,7 +563,14 @@ public:
         if (cext == ext) {
             basename = hugin_utils::stripExtension(basename);
         }
-        std::string outputfile = basename + "." + ext;
+        std::string outputfile(basename);
+        // append suffix if given
+        const std::string suffix = GetAdvancedOption(advOptions, "saveFinalImageSuffix", std::string());
+        if (!suffix.empty())
+        {
+            outputfile.append(suffix);
+        };
+        outputfile.append("." + ext);
         
 	// save the remapped image
         Base::m_progress->setMessage("saving result", hugin_utils::stripPath(outputfile));
