@@ -142,61 +142,14 @@ inline typename vigra::NumericTraits<typename Image::PixelType>::RealPromote Get
 template <class Image>
 void RestrictErrorToNextLevel(const Image & in, Image & out)
 {
-    typedef typename Image::PixelType ImagePixelType;
-    const int smallWidth = out.width() - 1;
-    const int smallHeight = out.height() - 1;
-#pragma omp parallel for schedule(dynamic, 100)
-    for (int y = 0; y < smallHeight; y++)
-    {
-        for (int x = 0; x < smallWidth; x++)
-        {
-            out[y][x] = in[2 * y][2 * x] + in[2 * y][2 * x + 1] + in[2 * y + 1][2 * x] + in[2 * y + 1][2 * x + 1];
-        };
-        // special case of most right pixel
-        ImagePixelType p2 = 0;
-        if (2 * smallWidth + 1 < in.width())
-        {
-            p2 = in[2 * y][2 * smallWidth + 1];
-        }
-        ImagePixelType p3 = 0;
-        ImagePixelType p4 = 0;
-        if (2 * y + 1 < in.height())
-        {
-            p3 = in[2 * y + 1][2 * smallWidth];
-            if (2 * smallWidth + 1 < in.width())
-            {
-                p4 = in[2 * y + 1][2 * smallWidth + 1];
-            };
-        };
-        out[y][smallWidth] = in[2 * y][2 * smallWidth] + p2 + p3 + p4;
-    };
-    // special case of last line
-    for (int x = 0; x < smallWidth; x++)
-    {
-        ImagePixelType p34 = 0;
-        if (2 * smallHeight + 1 < in.height())
-        {
-            p34 = in[2 * smallHeight + 1][2 * x] + in[2 * smallHeight + 1][2 * x + 1];
-        };
-        out[smallHeight][x] = in[2 * smallHeight][2 * x] + in[2 * smallHeight][2 * x + 1] + p34;
-    };
-    ImagePixelType p2 = 0;
-    if (2 * smallWidth + 1 < in.width())
-    {
-        p2 = in[2 * smallHeight][2 * smallWidth + 1];
-    }
-    ImagePixelType p3 = 0;
-    ImagePixelType p4 = 0;
-    if (2 * smallHeight + 1 < in.height())
-    {
-        p3 = in[2 * smallHeight + 1][2 * smallWidth];
-        if (2 * smallWidth + 1 < in.width())
-        {
-            p4 = in[2 * smallHeight + 1][2 * smallWidth + 1];
-        };
-    };
-    out[smallHeight][smallWidth] = in[2 * smallHeight][2 * smallWidth] + p2 + p3 + p4;
-};
+    // smooth input image
+    vigra::Kernel2D<double> filter2D;
+    filter2D.initExplicitly(vigra::Diff2D(-1, -1), vigra::Diff2D(1, 1)) = 0.25, 0.5, 0.25, 0.5, 1, 0.5, 0.25, 0.5, 0.25;
+    Image smoothImage(in.size());
+    vigra::convolveImage(vigra::srcImageRange(in), vigra::destImage(smoothImage), vigra::kernel2d(filter2D));
+    // downsample smoothed image
+    vigra::resizeImageNoInterpolation(vigra::srcImageRange(smoothImage), vigra::destImageRange(out));
+}
 
 // internal use by FindEdgesForPoisson
 struct FilterEdges
@@ -870,10 +823,8 @@ void Multigrid(Image& out, const Image& gradient, const vigra::ImagePyramid<Seam
     detail::CalcResidualError(err, out, gradient, seamMaskPyramid[maskIndex], doWrap);    // Fehler berechnen
     detail::RestrictErrorToNextLevel(err, err2);
     Multigrid(out2, err2, seamMaskPyramid, minLen, errorThreshold, maxIter, doWrap);
-    // when using a W cycle calculation another run of multigrid would follow
-    // Multigrid(out2, err2, seamMaskPyramid, minLen, errorThreshold, maxIter, doWrap); 
-    // this results in artefacts, maybe there is still a small error in other lines
-    // so trying to disable the W cycle and remain in a V cycle
+    // now do a W cycle calculation, another run of multigrid follows
+    Multigrid(out2, err2, seamMaskPyramid, minLen, errorThreshold, maxIter, doWrap); 
     vigra::resizeImageNoInterpolation(srcImageRange(out2), destImageRange(err)); 
     vigra::omp::combineTwoImagesIf(vigra::srcImageRange(out), vigra::srcImage(err),
         vigra::srcImage(seamMaskPyramid[maskIndex], MaskGreaterAccessor<typename SeamMask::PixelType>(2)),
