@@ -173,9 +173,6 @@ void PanoDetector::printDetails()
     {
         std::cout << "Automatically cache keypoints files to disc." << std::endl;
     };
-#ifdef HAVE_OPENMP
-    std::cout << "Number of threads  : " << (_cores>0 ? _cores : omp_get_max_threads()) << std::endl << std::endl;
-#endif
     std::cout << "Input image options" << std::endl;
     std::cout << "  Downscale to half-size : " << (_downscale?"yes":"no") << std::endl;
     if(_celeste)
@@ -463,7 +460,13 @@ void PanoDetector::run()
 #ifdef HAVE_OPENMP
     if (_cores == 0)
     {
-        setCores(omp_get_max_threads());
+        // use number of physical cores - 1
+        size_t nrCores = utils::GetPhysicalCPUCount();
+        if (nrCores > 4)
+        {
+            --nrCores;
+        };
+        setCores(nrCores);
     };
     if (maxImageSize != 0)
     {
@@ -494,6 +497,7 @@ void PanoDetector::run()
         };
     };
     omp_set_num_threads(_cores);
+    std::cout << "Using " << _cores << " threads" << std::endl;
 #endif
     RunnableVector queue;
     svmModel = NULL;
@@ -738,12 +742,6 @@ bool PanoDetector::match(std::vector<HuginBase::UIntSet> &checkedPairs)
 
 bool PanoDetector::loadProject()
 {
-    std::ifstream ptoFile(_inputFile.c_str());
-    if (ptoFile.bad())
-    {
-        std::cerr << "ERROR: could not open file: '" << _inputFile << "'!" << std::endl;
-        return false;
-    }
     _prefix=hugin_utils::getPathPrefix(_inputFile);
     if(_prefix.empty())
     {
@@ -759,11 +757,8 @@ bool PanoDetector::loadProject()
             _prefix=includeTrailingPathSep(_prefix);
         }
     };
-    _panoramaInfo->setFilePrefix(_prefix);
-    AppBase::DocumentData::ReadWriteError err = _panoramaInfo->readData(ptoFile);
-    if (err != AppBase::DocumentData::SUCCESSFUL)
+    if (!_panoramaInfo->ReadPTOFile(_inputFile, _prefix))
     {
-        std::cerr << "ERROR: couldn't parse panos tool script: '" << _inputFile << "'!" << std::endl;
         return false;
     }
 
@@ -771,6 +766,14 @@ bool PanoDetector::loadProject()
     // image options
     _panoramaInfoCopy=_panoramaInfo->duplicate();
 
+    // create a hash set for all known control points
+    {
+        const HuginBase::CPVector& allCps = _panoramaInfo->getCtrlPoints();
+        for (auto& cp : allCps)
+        {
+            _cpsHashSet.insert(cp.getCPString());
+        };
+    }
     // Add images found in the project file to _filesData
     const unsigned int nImg = _panoramaInfo->getNrOfImages();
     unsigned int imgWithKeyfile=0;
