@@ -913,6 +913,18 @@ int main2(std::vector<std::string> files, Parameters param)
                 };
             };
             // reoptimize
+            // check that we have enough control points left
+            if (pano.getNrOfCtrlPoints() < pano.getOptimizeVector().size())
+            {
+                std::cerr << std::endl << "After control points pruning there are only " << pano.getNrOfCtrlPoints() << " control points" << std::endl
+                    << "left, but you selected " << pano.getOptimizeVector().size() << " parameters to optimize." << std::endl
+                    << "This will give strange results." << std::endl
+                    << "Increase error distance (-t parameter), tweak cp" << std::endl
+                    << "detection parameters or select less parameters to optimize." << std::endl
+                    << std::endl
+                    << "Exiting..." << std::endl;
+                return 1;
+            }
             optimizeError = (HuginBase::PTools::optimize(pano) > 0);
         }
 
@@ -927,15 +939,23 @@ int main2(std::vector<std::string> files, Parameters param)
         };
 
         HuginBase::UIntSet imgs = pano.getActiveImages();
-        if (optimizeError)
+        // some check for valid output
+        HuginBase::UIntSet outputImages = HuginBase::getImagesinROI(pano, imgs);
+        if (optimizeError || outputImages.size() != imgs.size())
         {
             if (!param.ptoFile.empty())
             {
-                std::ofstream script(param.ptoFile.c_str());
-                pano.printPanoramaScript(script, optvars, pano.getOptions(), imgs, false, "");
+                pano.WritePTOFile(param.ptoFile);
             }
             std::cerr << "An error occurred during optimization." << std::endl;
-            std::cerr << "Try adding \"-p debug.pto\" and checking output." << std::endl;
+            if (param.ptoFile.empty())
+            {
+                std::cerr << "Try adding \"-p debug.pto\" and checking output." << std::endl;
+            }
+            else
+            {
+                std::cerr << "Check output file " << param.ptoFile << " for details." << std::endl;
+            };
             std::cerr << "Exiting..." << std::endl;
             return 1;
         }
@@ -1000,9 +1020,10 @@ int main2(std::vector<std::string> files, Parameters param)
         // At this point we have panorama options set according to the output
         if (!param.ptoFile.empty())
         {
-            std::ofstream script(param.ptoFile.c_str());
-            pano.printPanoramaScript(script, optvars, pano.getOptions(), imgs, false, "");
-            std::cout << "Written project file " << param.ptoFile << std::endl;
+            if (pano.WritePTOFile(param.ptoFile))
+            {
+                std::cout << "Written output to " << param.ptoFile << std::endl;
+            };
         }
 
 
