@@ -585,7 +585,7 @@ public:
 template <class SrcImgType, class AlphaImgType, class FlatImgType, class DestImgType>
 void correctImage(SrcImgType& srcImg,
                   const AlphaImgType& srcAlpha,
-                  const FlatImgType& srcFlat,
+                  FlatImgType& srcFlat,
                   HuginBase::SrcPanoImage src,
                   vigra_ext::Interpolator interpolator,
                   double maxValue,
@@ -621,14 +621,36 @@ void correctImage(SrcImgType& srcImg,
         };
 
         invResp.enforceMonotonicity();
-        if (src.getVigCorrMode() & HuginBase::SrcPanoImage::VIGCORR_FLATFIELD)
-        {
-            invResp.setFlatfield(&srcFlat);
-        }
+
         NullTransform transform;
         // dummy alpha channel
         vigra::BImage alpha(destImg.size());
+
+        if (src.getVigCorrMode() & HuginBase::SrcPanoImage::VIGCORR_FLATFIELD)
+        {
+            invResp.setFlatfield(&srcFlat);
+            // transform flatfield to linear space if needed
+            if (src.getResponseType() == HuginBase::BaseSrcPanoImage::RESPONSE_EMOR)
+            {
+                HuginBase::SrcPanoImage flatSrc;
+                flatSrc.setVigCorrMode(HuginBase::SrcPanoImage::VIGCORR_NONE);
+                HuginBase::Photometric::InvResponseTransform<SrcPixelType, SrcPixelType> invRespFlat(flatSrc);
+                invRespFlat.setHDROutput(true, 1.0);
+                if (maxValue != 1.0)
+                {
+                    vigra::transformImage(vigra::srcImageRange(srcFlat), vigra::destImage(srcFlat), vigra::functor::Arg1() / vigra::functor::Param(maxValue));
+                };
+                vigra_ext::transformImage(vigra::srcImageRange(srcFlat), vigra::destImageRange(srcFlat), vigra::destImage(alpha), vigra::Diff2D(0, 0), transform, invRespFlat, false, vigra_ext::INTERP_SPLINE_16, progress);
+            };
+            // smooth flatfield
+            vigra::gaussianSmoothing(vigra::srcImageRange(srcFlat), vigra::destImage(srcFlat), 20);
+            // calculate mean of flatfield and transform flat to vignetting correction values
+            vigra::FindAverage<typename FlatImgType::value_type> meanFlat;
+            vigra::inspectImage(vigra::srcImageRange(srcFlat), meanFlat);
+            vigra::transformImage(vigra::srcImageRange(srcFlat), vigra::destImage(srcFlat), vigra::functor::Arg1() / vigra::functor::Param(meanFlat.average()));
+        }
         vigra_ext::transformImage(srcImageRange(srcImg), destImageRange(srcImg), destImage(alpha), vigra::Diff2D(0, 0), transform, invResp, false, vigra_ext::INTERP_SPLINE_16, progress);
+
     }
 
     // radial distortion correction
